pub struct SocketAddrV4 { /* private fields */ }Expand description
An IPv4 socket address.
IPv4 socket addresses consist of an IPv4 address and a 16-bit port number, as
stated in IETF RFC 793.
See SocketAddr for a type encompassing both IPv4 and IPv6 socket addresses.
Portability
SocketAddrV4 is intended to be a portable representation of socket addresses and is likely not
the same as the internal socket address type used by the target operating systemโs API. Like all
repr(Rust) structs, however, its exact layout remains undefined and should not be relied upon
between builds.
Textual representation
SocketAddrV4 provides a FromStr implementation.
It accepts an IPv4 address in its textual representation, followed by a
single :, followed by the port encoded as a decimal integer. Other
formats are not accepted.
Examples
Implementations
Sourceimpl SocketAddrV4
impl SocketAddrV4
Sourcepub fn parse_ascii(b: &[u8]) -> Result<Self, AddrParseError>
๐ฌThis is a nightly-only experimental API. (addr_parse_ascii #101035)
pub fn parse_ascii(b: &[u8]) -> Result<Self, AddrParseError>
addr_parse_ascii #101035)Sourceimpl SocketAddrV4
impl SocketAddrV4
1.0.0 (const: 1.69.0) ยท Sourcepub const fn new(ip: Ipv4Addr, port: u16) -> SocketAddrV4
pub const fn new(ip: Ipv4Addr, port: u16) -> SocketAddrV4
Creates a new socket address from an IPv4 address and a port number.
Examples
1.0.0 (const: 1.69.0) ยท Sourcepub const fn ip(&self) -> &Ipv4Addr
pub const fn ip(&self) -> &Ipv4Addr
Returns the IP address associated with this socket address.
Examples
1.9.0 (const: 1.87.0) ยท Sourcepub const fn set_ip(&mut self, new_ip: Ipv4Addr)
pub const fn set_ip(&mut self, new_ip: Ipv4Addr)
Changes the IP address associated with this socket address.
Examples
1.0.0 (const: 1.69.0) ยท Sourcepub const fn port(&self) -> u16
pub const fn port(&self) -> u16
Returns the port number associated with this socket address.
Examples