SocketAddrV6

Struct SocketAddrV6 

1.77.0Source
pub struct SocketAddrV6 { /* private fields */ }
An IPv6 socket address.

IPv6 socket addresses consist of an IPv6 address, a 16-bit port number, as well as fields containing the traffic class, the flow label, and a scope identifier (see IETF RFC 2553, Section 3.3 for more details).

See SocketAddr for a type encompassing both IPv4 and IPv6 socket addresses.

Portability

SocketAddrV6 is intended to be a portable representation of socket addresses and is likely not the same as the internal socket address type used by the target operating system鈥檚 API. Like all repr(Rust) structs, however, its exact layout remains undefined and should not be relied upon between builds.

Textual representation

SocketAddrV6 provides a FromStr implementation, based on the bracketed format recommended by IETF RFC 5952, with scope identifiers based on those specified in IETF RFC 4007.

It accepts addresses consisting of the following elements, in order:

  • A left square bracket ([)
  • The textual representation of an IPv6 address
  • Optionally, a percent sign (%) followed by the scope identifier encoded as a decimal integer
  • A right square bracket (])
  • A colon (:)
  • The port, encoded as a decimal integer.

For example, the string [2001:db8::413]:443 represents a SocketAddrV6 with the address 2001:db8::413 and port 443. The string [2001:db8::413%612]:443 represents the same address and port, with a scope identifier of 612.

Other formats are not accepted.

Examples

use std::net::{Ipv6Addr, SocketAddrV6};

let socket = SocketAddrV6::new(Ipv6Addr::new(0x2001, 0xdb8, 0, 0, 0, 0, 0, 1), 8080, 0, 0);

assert_eq!("[2001:db8::1]:8080".parse(), Ok(socket));
assert_eq!(socket.ip(), &Ipv6Addr::new(0x2001, 0xdb8, 0, 0, 0, 0, 0, 1));
assert_eq!(socket.port(), 8080);

let mut with_scope = socket.clone();
with_scope.set_scope_id(3);
assert_eq!("[2001:db8::1%3]:8080".parse(), Ok(with_scope));

Implementations

impl SocketAddrV6

pub fn parse_ascii(b: &[u8]) -> Result<Self, AddrParseError>

馃敩This is a nightly-only experimental API. (addr_parse_ascii #101035)

Parse an IPv6 socket address from a slice of bytes.

#![feature(addr_parse_ascii)]

use std::net::{Ipv6Addr, SocketAddrV6};

let socket = SocketAddrV6::new(Ipv6Addr::new(0x2001, 0xdb8, 0, 0, 0, 0, 0, 1), 8080, 0, 0);

assert_eq!(SocketAddrV6::parse_ascii(b"[2001:db8::1]:8080"), Ok(socket));
impl SocketAddrV6

1.0.0 (const: 1.69.0)Source

pub const fn new( ip: Ipv6Addr, port: u16, flowinfo: u32, scope_id: u32, ) -> SocketAddrV6

Creates a new socket address from an IPv6 address, a 16-bit port number, and the flowinfo and scope_id fields.

For more information on the meaning and layout of the flowinfo and scope_id parameters, see IETF RFC 2553, Section 3.3.

Examples
use std::net::{SocketAddrV6, Ipv6Addr};

let socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 0);
1.0.0 (const: 1.69.0)Source

pub const fn ip(&self) -> &Ipv6Addr

Returns the IP address associated with this socket address.

Examples
use std::net::{SocketAddrV6, Ipv6Addr};

let socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 0);
assert_eq!(socket.ip(), &Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1));
1.9.0 (const: 1.87.0)Source

pub const fn set_ip(&mut self, new_ip: Ipv6Addr)

Changes the IP address associated with this socket address.

Examples
use std::net::{SocketAddrV6, Ipv6Addr};

let mut socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 0);
socket.set_ip(Ipv6Addr::new(76, 45, 0, 0, 0, 0, 0, 0));
assert_eq!(socket.ip(), &Ipv6Addr::new(76, 45, 0, 0, 0, 0, 0, 0));
1.0.0 (const: 1.69.0)Source

pub const fn port(&self) -> u16

Returns the port number associated with this socket address.

Examples
use std::net::{SocketAddrV6, Ipv6Addr};

let socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 0);
assert_eq!(socket.port(), 8080);
1.9.0 (const: 1.87.0)Source

pub const fn set_port(&mut self, new_port: u16)

Changes the port number associated with this socket address.

Examples
use std::net::{SocketAddrV6, Ipv6Addr};

let mut socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 0);
socket.set_port(4242);
assert_eq!(socket.port(), 4242);
1.0.0 (const: 1.69.0)Source

pub const fn flowinfo(&self) -> u32

Returns the flow information associated with this address.

This information corresponds to the sin6_flowinfo field in C鈥檚 netinet/in.h, as specified in IETF RFC 2553, Section 3.3. It combines information about the flow label and the traffic class as specified in IETF RFC 2460, respectively Section 6 and Section 7.

Examples
use std::net::{SocketAddrV6, Ipv6Addr};

let socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 10, 0);
assert_eq!(socket.flowinfo(), 10);
1.9.0 (const: 1.87.0)Source

pub const fn set_flowinfo(&mut self, new_flowinfo: u32)

Changes the flow information associated with this socket address.

See SocketAddrV6::flowinfo鈥檚 documentation for more details.

Examples
use std::net::{SocketAddrV6, Ipv6Addr};

let mut socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 10, 0);
socket.set_flowinfo(56);
assert_eq!(socket.flowinfo(), 56);
1.0.0 (const: 1.69.0)Source

pub const fn scope_id(&self) -> u32

Returns the scope ID associated with this address.

This information corresponds to the sin6_scope_id field in C鈥檚 netinet/in.h, as specified in IETF RFC 2553, Section 3.3.

Examples
use std::net::{SocketAddrV6, Ipv6Addr};

let socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 78);
assert_eq!(socket.scope_id(), 78);
1.9.0 (const: 1.87.0)Source

pub const fn set_scope_id(&mut self, new_scope_id: u32)

Changes the scope ID associated with this socket address.

See SocketAddrV6::scope_id鈥檚 documentation for more details.

Examples
use std::net::{SocketAddrV6, Ipv6Addr};

let mut socket = SocketAddrV6::new(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1), 8080, 0, 78);
socket.set_scope_id(42);
assert_eq!(socket.scope_id(), 42);